'use strict';

const blackListedProjectNames = ['react', 'test', 'app'];
const {logger, doesDirectoryExist, installPackages} = require('../utils/helperLoader');
const shell = require('shelljs');
const fs = require('fs');
const cwd = process.cwd();

module.exports = function (args, cb) {
    const name = args.name;

    // Check to see if folder already exists...
    if (doesDirectoryExist(cwd, name)) {
        logger('error', 'Directory or project already exists. Exiting generation process.');
    }

    if (blackListedProjectNames.indexOf(name) > -1)
        logger('error', 'Your project name can not contain react, test or app.');

    // Install React APP
    logger('info', 'Installing React App...');
    if (shell.exec(`create-react-app ${name}`).code !== 0) {
        logger('error', 'Could not generate React Application.');
    } else {
        logger('success', 'Successfully generated project. Happy Coding!');
    }

    // Install React-CLI
    installPackages(name);

    // Install Flux
    try {
        if (args.options.flux) {
            logger('info', 'Installing Flux...');
            installFlux(name, ['flux']);
        }
    } catch (error) {
        return error;
    }

    function installFlux(name, packages = []) {
        installPackages(name, packages);
    }

    cb();
};