"use strict";

const fs = require('fs');
const colors = require('colors');
const isInstalled = require('is-installed');
const shell = require('shelljs');

colors.setTheme({
    info: 'green',
    white: 'white',
    help: 'cyan',
    warn: 'yellow',
    error: 'red'
});

/**
 * File names should be capitalized with generating new files
 * @param str
 */
module.exports.fileNameCapitalize = function (str) {
    console.log(str);
};

module.exports.logger = function (type, message) {
    if (type === 'error') {
        console.log(colors.red(`${message}`));
        return;
    } else if (type === 'success') {
        console.log(colors.green(`${message}`));
        return;
    } else if (type === 'info') {
        console.log(colors.cyan(`${message}`));
        return;
    }
    console.log(message);
};

module.exports.shouldUseYarn = isInstalled.sync('yarn');

module.exports.installPackages = function (projectName, packages) {
    let directory = `${projectName}`;
    if (!fs.existsSync(directory)) {
        console.log(colors.red('Could not install required packages. The required project directory does not exist.'));
        return null;
    }

    let packagesJoined = packages.join(' ');

    console.log(packagesJoined);

    shell.exec(`cd ${projectName}; yarn add ${packagesJoined}`);
};

module.exports.doesDirectoryExist = function (path, folder) {
    return fs.exists(`${path}/${folder}`);
};